@@ -12,9 +12,7 @@ from calibre import force_unicode, prepare_string_for_xml
 from calibre.constants import filesystem_encoding
 from calibre.db.constants import DATA_DIR_NAME
 from calibre.ebooks.metadata import fmt_sidx, rating_to_stars
-from calibre.ebooks.metadata.search_internet import (
-    DEFAULT_AUTHOR_SOURCE, name_for, qquote, url_for_author_search, url_for_book_search,
-)
+from calibre.ebooks.metadata.search_internet import DEFAULT_AUTHOR_SOURCE, name_for, qquote, url_for_author_search, url_for_book_search
 from calibre.ebooks.metadata.sources.identify import urls_from_identifiers
 from calibre.library.comments import comments_to_html, markdown
 from calibre.utils.date import format_date, is_date_undefined
@@ -133,7 +131,7 @@ def mi_to_html(
             note = ''
             item_id = None if item_id_if_has_note is None else item_id_if_has_note(field, field_value)
             if item_id is not None:
-                note = ' <a title="{0}" href="{1}">{2}</a>'.format(
+                note = ' <a title="{}" href="{}">{}</a>'.format(
                     _('Show notes for: {}').format(field_value), notes_action(field=field, value=field_value, item_id=item_id), note_markup)
             return link + note
         return ''
