@@ -7,19 +7,24 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 import re
 from collections import namedtuple
 from functools import partial
+
 from qt.core import QFont, QTextBlockUserData, QTextCharFormat, QVariant
 
 from calibre.ebooks.oeb.polish.spell import html_spell_tags, patterns, xml_spell_tags
 from calibre.gui2.tweak_book import dictionaries, tprefs, verify_link
 from calibre.gui2.tweak_book.editor import (
-    CLASS_ATTRIBUTE_PROPERTY, LINK_PROPERTY, SPELL_LOCALE_PROPERTY, SPELL_PROPERTY,
-    TAG_NAME_PROPERTY, store_locale, syntax_text_char_format
+    CLASS_ATTRIBUTE_PROPERTY,
+    LINK_PROPERTY,
+    SPELL_LOCALE_PROPERTY,
+    SPELL_PROPERTY,
+    TAG_NAME_PROPERTY,
+    store_locale,
+    syntax_text_char_format,
 )
 from calibre.gui2.tweak_book.editor.syntax.base import SyntaxHighlighter, run_loop
-from calibre.gui2.tweak_book.editor.syntax.css import (
-    CSSState, CSSUserData, create_formats as create_css_formats,
-    state_map as css_state_map
-)
+from calibre.gui2.tweak_book.editor.syntax.css import CSSState, CSSUserData
+from calibre.gui2.tweak_book.editor.syntax.css import create_formats as create_css_formats
+from calibre.gui2.tweak_book.editor.syntax.css import state_map as css_state_map
 from calibre.spell.break_iterator import split_into_words_and_positions
 from calibre.spell.dictionary import parse_lang_code
 from calibre_extensions import html_syntax_highlighter as _speedup
@@ -521,6 +526,7 @@ class XMLHighlighter(Highlighter):
 
 def profile():
     import sys
+
     from qt.core import QTextDocument
 
     from calibre.gui2 import Application
