@@ -11,21 +11,18 @@ from collections import defaultdict
 from datetime import datetime
 from functools import partial
 from itertools import count
-from lxml.etree import Comment
 from math import ceil
 
+from lxml.etree import Comment
+
 from calibre import detect_ncpus, force_unicode, prepare_string_for_xml
 from calibre.constants import iswindows
 from calibre.customize.ui import plugin_for_input_format
-from calibre.ebooks.oeb.base import (
-    EPUB, OEB_DOCS, OEB_STYLES, OPF, SMIL, XHTML, XHTML_NS, XLINK, XPath as _XPath,
-    rewrite_links, urlunquote,
-)
+from calibre.ebooks.oeb.base import EPUB, OEB_DOCS, OEB_STYLES, OPF, SMIL, XHTML, XHTML_NS, XLINK, rewrite_links, urlunquote
+from calibre.ebooks.oeb.base import XPath as _XPath
 from calibre.ebooks.oeb.iterator.book import extract_book
 from calibre.ebooks.oeb.polish.container import Container as ContainerBase
-from calibre.ebooks.oeb.polish.cover import (
-    find_cover_image, find_cover_image_in_page, find_cover_page,
-)
+from calibre.ebooks.oeb.polish.cover import find_cover_image, find_cover_image_in_page, find_cover_page
 from calibre.ebooks.oeb.polish.toc import from_xpaths, get_landmarks, get_toc
 from calibre.ebooks.oeb.polish.utils import guess_type
 from calibre.ptempfile import PersistentTemporaryDirectory
@@ -39,10 +36,9 @@ from calibre.utils.serialize import json_dumps, json_loads, msgpack_dumps, msgpa
 from calibre.utils.short_uuid import uuid4
 from calibre_extensions import speedup
 from calibre_extensions.fast_css_transform import transform_properties
-from polyglot.binary import (
-    as_base64_unicode as encode_component, from_base64_bytes,
-    from_base64_unicode as decode_component,
-)
+from polyglot.binary import as_base64_unicode as encode_component
+from polyglot.binary import from_base64_bytes
+from polyglot.binary import from_base64_unicode as decode_component
 from polyglot.builtins import as_bytes, iteritems
 from polyglot.urllib import quote, urlparse
 
@@ -354,9 +350,12 @@ def transform_smil(container, name, link_uid, virtualize_resources, virtualized_
     text_tag, audio_tag = SMIL('text'), SMIL('audio')
     body_tag, seq_tag, par_tag = SMIL('body'), SMIL('seq'), SMIL('par')
     type_attr, textref_attr = EPUB('type'), EPUB('textref')
+    parnum = 0
 
-    def make_par(par):
-        ans = {}
+    def make_par(par, target):
+        nonlocal parnum
+        parnum += 1
+        ans = {'num': parnum}
         t = par.get(type_attr)
         if t:
             ans['type'] = t
@@ -364,7 +363,10 @@ def transform_smil(container, name, link_uid, virtualize_resources, virtualized_
             if child.tag == text_tag:
                 src = child.get('src')
                 if src:
-                    ans['text'] = [container.href_to_name(child.get('src'), name), src.partition('#')[2]]
+                    q = container.href_to_name(src, name)
+                    if q != target:
+                        return {}  # the par must match the textref of the parent seq
+                    ans['anchor'] = src.partition('#')[2]
             elif child.tag == audio_tag:
                 src = child.get('src')
                 if src:
@@ -386,10 +388,15 @@ def transform_smil(container, name, link_uid, virtualize_resources, virtualized_
             parent_seq = smil_map.get(target)
             if parent_seq is None:
                 smil_map[target] = parent_seq = {'textref': [target, ''], 'par':[], 'seq':[], 'type': 'root'}
+        else:
+            if parent_seq['textref'][0] != target:
+                return  # child seqs must be in the same HTML file as parent
         parent_seq['seq'].append(seq)
         for child in seq_xml_element.iterchildren('*'):
             if child.tag == par_tag:
-                seq['par'].append(make_par(child))
+                p = make_par(child, target)
+                if p.get('audio'):
+                    seq['par'].append(p)
             elif child.tag == seq_tag:
                 tref = child.get(textref_attr)
                 if tref:
@@ -432,7 +439,7 @@ def transform_inline_styles(container, name, transform_sheet, transform_style):
 
 
 def transform_html(container, name, virtualize_resources, link_uid, link_to_map, virtualized_names):
-    link_xpath = XPath('//h:a[@href]')
+    link_xpath = XPath('//h:*[@href and (self::h:a or self::h:area)]')
     svg_link_xpath = XPath('//svg:a')
     img_xpath = XPath('//h:img[@src]')
     svg_img_xpath = XPath('//svg:image[@xl:href]')
@@ -604,7 +611,7 @@ def worker_main():
 def virtualize_html(container, name, link_uid, link_to_map, virtualized_names):
 
     changed = set()
-    link_xpath = XPath('//h:a[@href]')
+    link_xpath = XPath('//h:*[@href and (self::h:a or self::h:area)]')
     svg_link_xpath = XPath('//svg:a')
     link_replacer = create_link_replacer(container, link_uid, changed)
 
